pub struct AgentOutput {
pub status: i32,
pub outputs: Option<Value>,
pub error: String,
pub exception: String,
}Expand description
Agent output.
Fields
status: i32agent execution status
outputs: Option<Value>agent outputs
error: Stringagent error message
exception: Stringagent exception message
Implementations
Sourceimpl AgentOutput
impl AgentOutput
Sourcepub fn status(&self) -> NodeExecutionStatus
pub fn status(&self) -> NodeExecutionStatus
Returns the enum value of status, or the default if the field is set to an invalid enum value.
Sourcepub fn set_status(&mut self, value: NodeExecutionStatus)
pub fn set_status(&mut self, value: NodeExecutionStatus)
Sets status to the provided enum value.